==> v3.3.11.zip: cost-benefit-projection/README.md <==
# Cost Benefit Projection (3.3.11)

This is a [Joomla 3.x] (http://www.joomla.org/) component.

 ![Cost Benefit Projection image] (https://raw.githubusercontent.com/namibia/CBP-Joomla-3-Component/master/admin/assets/images/component-300.png "The Cost Benefit Projection")

[Create Epidemiological Profiles] (https://www.staffhealthcbp.com/) for diseases and risks affecting your company. Detailed information on projected work days lost and costs. Create and edit activities and wellness responses for your workplace. Access to Small Business Modelling. Results displayed by gender. Network with other companies and wellness professionals.

Having seen the health priorities for your workforce, the tool outputs projections for how the interventions – which you have designed - are expected to benefit the company financially.

Benefits are calculated based on the model projecting reductions in workdays lost due to sickness, presenteeism and death.

# Requirements

Due to the size of the permissional structure, you will need to increase max_input_vars until the permissions are able to save.
```
max_input_vars = 5000
```
# Build Details

+ *Company*: [Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb] (https://www.staffhealthcbp.com/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Cost Benefit Projection] (https://www.staffhealthcbp.com/)
+ *First Build*: 15th June, 2012
+ *Last Build*: 5th April, 2016
+ *Version*: 3.3.11
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
+ *Line count*: **84036**
+ *File count*: **559**
+ *Folder count*: **101**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)

==> v3.4.2.zip: cost-benefit-projection/README.md <==
# Cost Benefit Projection (3.4.2)

This is a [Joomla 3.x] (http://www.joomla.org/) component.

 ![Cost Benefit Projection image] (https://raw.githubusercontent.com/namibia/CBP-Joomla-3-Component/master/admin/assets/images/component-300.png "The Cost Benefit Projection")

[Create Epidemiological Profiles] (https://www.staffhealthcbp.com/) for diseases and risks affecting your company. Detailed information on projected work days lost and costs. Create and edit activities and wellness responses for your workplace. Access to Small Business Modelling. Results displayed by gender. Network with other companies and wellness professionals.

Having seen the health priorities for your workforce, the tool outputs projections for how the interventions – which you have designed - are expected to benefit the company financially.

Benefits are calculated based on the model projecting reductions in workdays lost due to sickness, presenteeism and death.

# Requirements

Due to the size of the permissional structure, you will need to increase max_input_vars until the permissions are able to save.
```
max_input_vars = 5000
```
# Build Details

+ *Company*: [Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb] (https://www.staffhealthcbp.com/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Cost Benefit Projection] (https://www.staffhealthcbp.com/)
+ *First Build*: 15th June, 2012
+ *Last Build*: 27th June, 2016
+ *Version*: 3.4.2
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
+ *Line count*: **91667**
+ *File count*: **572**
+ *Folder count*: **103**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)
